Index: ios/chrome/browser/payments/payment_request_utils.h |
diff --git a/ios/chrome/browser/payments/payment_request_utils.h b/ios/chrome/browser/payments/payment_request_utils.h |
index c158515b2ee73820673eee617f4185b15e9f552d..9a6493aab03a12adde28d2b7b6ce515e2930f0b6 100644 |
--- a/ios/chrome/browser/payments/payment_request_utils.h |
+++ b/ios/chrome/browser/payments/payment_request_utils.h |
@@ -13,7 +13,10 @@ class AutofillProfile; |
namespace payment_request_utils { |
-// Helper function to get the shipping address label from an autofill profile. |
+// Helper function to get the name label from an autofill profile. |
+NSString* NameLabelFromAutofillProfile(autofill::AutofillProfile* profile); |
+ |
+// Helper function to get the address label from an autofill profile. |
NSString* AddressLabelFromAutofillProfile(autofill::AutofillProfile* profile); |
// Helper function that returns a formatted currency string given the value and |
@@ -21,6 +24,10 @@ NSString* AddressLabelFromAutofillProfile(autofill::AutofillProfile* profile); |
NSString* FormattedCurrencyString(NSDecimalNumber* value, |
NSString* currencyCode); |
+// Helper function to get the phone number label from an autofill profile. |
+NSString* PhoneNumberLabelFromAutofillProfile( |
+ autofill::AutofillProfile* profile); |
+ |
} // namespace payment_request_utils |
#endif // IOS_CHROME_BROWSER_PAYMENTS_PAYMENT_REQUEST_UTILS_H_ |